@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "treeview" "1.3.0"
+(define-package "treeview" "20241101.115"
   "A generic tree navigation library."
-  '((emacs "29.1"))
+  '((emacs "25.1"))
   :url "https://github.com/tilmanrassy/emacs-treeview"
-  :commit "f8b678ba1dd52171002585bfc13921a509658af3"
-  :revdesc "v1.3.0-0-gf8b678ba1dd5"
+  :commit "9a1a16f84fc3c368443641f7a71aa2407ad91d38"
+  :revdesc "9a1a16f84fc3"
   :keywords '("lisp" "tools" "internal" "convenience")
   :authors '(("Tilman Rassy" . "tilman.rassy@googlemail.com"))
   :maintainers '(("Tilman Rassy" . "tilman.rassy@googlemail.com")))
